@@ -56,12 +56,13 @@ class ExtendedAttributes:
 
 	def read_from_rp(self, rp):
 		"""Set the extended attributes from an rpath"""
-		try: attr_list = rp.conn.xattr.listxattr(rp.path, rp.issym())
+		try:
+			attr_list = rp.conn.xattr.listxattr(rp.path, rp.issym())
 		except IOError, exc:
 			if exc[0] in (errno.EOPNOTSUPP, errno.EPERM, errno.ETXTBSY):
 				return # if not supported, consider empty
-			if exc[0] == errno.EACCES or exc[0] == errno.ENOENT:
-				log.Log("Warning: listattr(%s): %s" % (repr(rp.path), exc), 3)
+			if exc[0] in (errno.EACCES, errno.ENOENT, errno.ELOOP):
+				log.Log("Warning: listattr(%s): %s" % (repr(rp.path), exc), 4)
 				return
 			raise
 		for attr in attr_list:
@@ -71,11 +72,15 @@ class ExtendedAttributes:
 			if not rp.isdir() and attr == 'com.apple.ResourceFork':
 				# Resource Fork handled elsewhere, except for directories
 				continue
-			try: self.attr_dict[attr] = rp.conn.xattr.getxattr(rp.path, attr, rp.issym())
+			try:
+				self.attr_dict[attr] = \
+					rp.conn.xattr.getxattr(rp.path, attr, rp.issym())
 			except IOError, exc:
 				# File probably modified while reading, just continue
 				if exc[0] == errno.ENODATA: continue
 				elif exc[0] == errno.ENOENT: break
+				# Handle bug in pyxattr < 0.2.2
+				elif exc[0] == errno.ERANGE: continue
 				else: raise
 
 	def clear_rp(self, rp):
@@ -111,7 +116,7 @@ class ExtendedAttributes:
 				# Mac and Linux attributes have different namespaces, so
 				# fail gracefully if can't call setxattr
 				if exc[0] in (errno.EOPNOTSUPP, errno.EPERM, errno.EACCES,
-						errno.ENOENT):
+						errno.ENOENT, errno.EINVAL):
 					log.Log("Warning: unable to write xattr %s to %s"
 							% (name, repr(rp.path)), 6)
 					continue
@@ -224,7 +229,7 @@ class AccessControlLists:
 		"""Set self.entry_list and self.default_entry_list from text"""
 		self.entry_list, self.default_entry_list = [], []
 		for line in text.split('\n'):
-			comment_pos = text.find('#')
+			comment_pos = line.find('#')
 			if comment_pos >= 0: line = line[:comment_pos]
 			line = line.strip()
 			if not line: continue
